<?php
namespace Barn2\Plugin\WC_Lead_Time\Admin\Wizard;

use Barn2\Plugin\WC_Lead_Time\Admin\Wizard\Steps\Completed;
use Barn2\Plugin\WC_Lead_Time\Admin\Wizard\Steps\Display;
use Barn2\Plugin\WC_Lead_Time\Admin\Wizard\Steps\Lead_Time;
use Barn2\Plugin\WC_Lead_Time\Admin\Wizard\Steps\License_Verification;
use Barn2\Plugin\WC_Lead_Time\Admin\Wizard\Steps\Stock_Status;
use Barn2\Plugin\WC_Lead_Time\Admin\Wizard\Steps\Upsell;
use Barn2\Plugin\WC_Lead_Time\Dependencies\Setup_Wizard\Setup_Wizard as Wizard;
use Barn2\Plugin\WC_Lead_Time\Dependencies\Lib\Plugin\License\EDD_Licensing;
use Barn2\Plugin\WC_Lead_Time\Dependencies\Lib\Plugin\License\Plugin_License;
use Barn2\Plugin\WC_Lead_Time\Dependencies\Lib\Plugin\Licensed_Plugin;
use Barn2\Plugin\WC_Lead_Time\Dependencies\Lib\Registerable;

class Setup_Wizard implements Registerable {

	private $plugin;

	public $wizard;

	public function __construct( Licensed_Plugin $plugin ) {

		$this->plugin = $plugin;

		$steps = [
			new License_Verification(),
			new Display(),
			new Stock_Status(),
			new Lead_Time(),
			new Upsell(),
			new Completed(),
		];

		$wizard = new Wizard( $this->plugin, $steps );

		$wizard->configure(
			[
				'skip_url'        => admin_url( 'admin.php?page=wc-settings&tab=products&section=lead-time' ),
				'license_tooltip' => esc_html__( 'The licence key is contained in your order confirmation email.', 'woocommerce-lead-time' ),
			]
		);

		$wizard->add_edd_api( EDD_Licensing::class );
		$wizard->add_license_class( Plugin_License::class );

		$this->wizard = $wizard;
	}

	/**
	 * Boot services.
	 *
	 * @return void
	 */
	public function register() {
		$this->wizard->boot();

		add_action( 'admin_footer', [ $this, 'enqueue_wiz_restart' ] );
		add_action( 'admin_footer', [ $this, 'enqueue_wizard_custom_styling' ] );
	}

	/**
	 * Enqueue the assets for the restart button.
	 *
	 * @return void
	 */
	public function enqueue_wiz_restart() {
		if ( ! $this->wizard->is_wc_settings_screen( 'lead-time' ) ) {
			return;
		}

        echo $this->wizard->load_wizard_restart_assets(); //phpcs:ignore
	}

	public function enqueue_wizard_custom_styling() {

		$screen = get_current_screen();

		if ( $screen->base !== 'toplevel_page_woocommerce-lead-time-setup-wizard' ) {
			return;
		}

		?>
		<style>
			.barn2-wizard-input.input-heading, .no-margin-checkbox {
				margin-bottom: 0.5rem !important;
			}
		</style>
		<?php
	}

}
