<?php
namespace Barn2\Plugin\WC_Lead_Time\Admin\Wizard\Steps;

use Barn2\Plugin\WC_Lead_Time\Dependencies\Setup_Wizard\Api;
use Barn2\Plugin\WC_Lead_Time\Dependencies\Setup_Wizard\Step;
use Barn2\Plugin\WC_Lead_Time\Util;

class Lead_Time extends Step {

	/**
	 * {@inheritdoc}
	 */
	public function __construct() {
		$this->set_id( 'lead-time' );
		$this->set_name( esc_html__( 'Global lead time', 'woocommerce-lead-time' ) );
		$this->set_title( esc_html__( 'Global lead time', 'woocommerce-lead-time' ) );
		$this->set_description( esc_html__( 'Optionally set a lead time which will be used on all products. You can override this for specific categories, products and variations.', 'woocommerce-lead-time' ) );
		$this->set_tooltip( esc_html__( 'If you want to set a different lead time for each stock status then you can do this on the plugin settings page in a minute.', 'woocommerce-lead-time' ) );
	}

	/**
	 * {@inheritdoc}
	 */
	public function setup_fields() {
		$fields = [];

		$fields['lead_time_prefix'] = [
			'type'        => 'text',
			'label'       => esc_html__( 'Lead time prefix', 'woocommerce-lead-time' ),
			'description' => __( 'Add text to appear before all lead times, e.g. "Lead time:"', 'woocommerce-lead-time' ),
			'value'       => get_option( 'wclt_prefix', '' )
		];

		$fields['lead_time_format'] = [
			'type'    => 'select',
			'label'   => esc_html__( 'Global lead time format', 'woocommerce-lead-time' ),
			'value'   => Util::get_global_lead_time_format(),
			'options' => [
				[
					'value' => 'static',
					'label' => __( 'Static', 'woocommerce-lead-time' )
				],
				[
					'value' => 'dynamic',
					'label' => __( 'Dynamic', 'woocommerce-lead-time' )
				]
			]
		];

		$fields['wclt_dynamic_type'] = [
			'type'	  => 'select',
			'label'		=> __( 'Display format', 'woocommerce-lead-time' ),
			'value'		=> get_option( 'wclt_dynamic_type', 'units' ),
			'options'	=> [
				[
					'value' => 'units',
					'label' => __( 'Units', 'woocommerce-lead-time' )
				],
				[
					'value' => 'date',
					'label' => __( 'Date', 'woocommerce-lead-time' )
				]
			]
		];

		$fields['lead_time_units_heading'] = [
			'type'  => 'heading',
			'label' => esc_html__( 'Lead time units', 'woocommerce-lead-time' ),
			'style' => [
				'fontSize' => '13px'
			]
		];

		$fields['wclt_days_unit'] = [
			'type'    => 'checkbox',
			'label'   => esc_html__( 'Days', 'woocommerce-lead-time' ),
			'value'   => get_option( 'wclt_days_unit', 'yes' ) === 'yes'
		];
		
		$fields['wclt_weeks_unit'] = [
			'type'    => 'checkbox',
			'label'   => esc_html__( 'Weeks', 'woocommerce-lead-time' ),
			'value'   => get_option( 'wclt_weeks_unit', 'no' ) === 'yes'
		];

		$fields['wclt_months_unit'] = [
			'type'    => 'checkbox',
			'label'   => esc_html__( 'Months', 'woocommerce-lead-time' ),
			'value'   => get_option( 'wclt_months_unit', 'no' ) === 'yes'
		];

		return $fields;
	}

	/**
	 * {@inheritdoc}
	 */
	public function submit( array $values ) {

		$prefix = isset( $values['lead_time_prefix'] ) ? $values['lead_time_prefix'] : '';
		$format = $values['lead_time_format'];
		$units  = $values['wclt_units'];

		update_option( 'wclt_prefix', $prefix );
		update_option( 'wclt_global_format', $format );
		update_option( 'wclt_units', $units );

		return Api::send_success_response();
	}

}
