<?php
namespace Barn2\Plugin\WC_Lead_Time\Admin\Wizard\Steps;

use Barn2\Plugin\WC_Lead_Time\Dependencies\Setup_Wizard\Api;
use Barn2\Plugin\WC_Lead_Time\Dependencies\Setup_Wizard\Step;

class Stock_Status extends Step {

	/**
	 * {@inheritdoc}
	 */
	public function __construct() {
		$this->set_id( 'status' );
		$this->set_name( esc_html__( 'Stock status', 'woocommerce-lead-time' ) );
		$this->set_title( esc_html__( 'Stock statuses', 'woocommerce-lead-time' ) );
		$this->set_description( esc_html__( 'Which stock statuses do you want to display lead times for?', 'woocommerce-lead-time' ) );
	}

	/**
	 * {@inheritdoc}
	 */
	public function setup_fields() {
		$fields = [];

		$fields['display_heading2'] = [
			'type'  => 'heading',
			'label' => esc_html__( 'Display lead times for', 'woocommerce-lead-time' ),
			'style' => [
				'fontSize' => '13px'
			]
		];

		$fields['wclt_display_in_stock'] = [
			'type'    => 'checkbox',
			'label'   => esc_html__( 'In stock products', 'woocommerce-lead-time' ),
			'value'   => get_option( 'wclt_display_in_stock', 'yes' ) === 'yes',
			'classes' => [ 'no-margin-checkbox' ]
		];

		$fields['wclt_display_out_stock'] = [
			'type'    => 'checkbox',
			'label'   => esc_html__( 'Out of stock products', 'woocommerce-lead-time' ),
			'value'   => get_option( 'wclt_display_out_stock' ) === 'yes',
			'classes' => [ 'no-margin-checkbox' ]
		];

		$fields['wclt_display_backorder'] = [
			'type'  => 'checkbox',
			'label' => esc_html__( 'Products on backorder', 'woocommerce-lead-time' ),
			'value' => get_option( 'wclt_display_backorder' ) === 'yes',
		];

		return $fields;
	}

	private function get_bool_value( $value ) {
		return $value === '1' || $value === true || $value === 'true' ? 'yes' : 'no';
	}

	/**
	 * {@inheritdoc}
	 */
	public function submit( array $values ) {
		$in_stock     = $values['wclt_display_in_stock'];
		$out_of_stock = $values['wclt_display_out_stock'];
		$backorder    = $values['wclt_display_backorder'];

		update_option( 'wclt_display_in_stock', $this->get_bool_value( $in_stock ) );
		update_option( 'wclt_display_out_stock', $this->get_bool_value( $out_of_stock ) );
		update_option( 'wclt_display_backorder', $this->get_bool_value( $backorder ) );

		return Api::send_success_response();
	}

}
